@@ -110,6 +110,13 @@ DEVICES = [{
 SECTOR_START = 79267840
 SECTOR_END = 488265727
 SGDISK_LARGEST = "%s\n%s\n" % (SECTOR_START, SECTOR_END)
+SGDISK_V = """
+Problem: The secondary header's self-pointer indicates that it doesn't reside
+at the end of the disk. If you've added a disk to a RAID array, use the 'e'
+option on the experts' menu to adjust the secondary header's and partition
+table's locations.
+
+Identified 1 problems!"""
 
 # output of vgs --noheadings --options vg_name
 VGS = "  vg\n"
@@ -147,10 +154,10 @@ class TestGrowvols(base.BaseTestCase):
 
     def test_convert_bytes(self):
         self.assertEqual('100B', growvols.convert_bytes(100))
-        self.assertEqual('1KB', growvols.convert_bytes(1000))
-        self.assertEqual('2MB', growvols.convert_bytes(2000000))
-        self.assertEqual('3GB', growvols.convert_bytes(3000000000))
-        self.assertEqual('4TB', growvols.convert_bytes(4000000000000))
+        self.assertEqual('1000B', growvols.convert_bytes(1000))
+        self.assertEqual('1MiB', growvols.convert_bytes(2000000))
+        self.assertEqual('2GiB', growvols.convert_bytes(3000000000))
+        self.assertEqual('3725GiB', growvols.convert_bytes(4000000000000))
 
     @mock.patch('subprocess.Popen')
     def test_execute(self, mock_popen):
@@ -465,6 +472,9 @@ class TestGrowvols(base.BaseTestCase):
         # noop, only discover block device info
         mock_execute.side_effect = [
             LSBLK,
+            SGDISK_V,
+            '',
+            '',
             SGDISK_LARGEST,
             VGS,
             LVS,
@@ -473,6 +483,9 @@ class TestGrowvols(base.BaseTestCase):
         mock_execute.assert_has_calls([
             mock.call(['lsblk', '-Po',
                        'kname,pkname,name,label,type,fstype,mountpoint']),
+            mock.call(['sgdisk', '-v', '/dev/sda']),
+            mock.call(['sgdisk', '-e', '/dev/sda']),
+            mock.call(['partprobe']),
             mock.call(['sgdisk', '--first-aligned-in-largest',
                        '--end-of-largest', '/dev/sda']),
             mock.call(['vgs', '--noheadings', '--options', 'vg_name']),
@@ -484,6 +497,7 @@ class TestGrowvols(base.BaseTestCase):
         mock_execute.reset_mock()
         mock_execute.side_effect = [
             LSBLK,
+            '',
             SGDISK_LARGEST,
             VGS,
             LVS,
@@ -493,6 +507,7 @@ class TestGrowvols(base.BaseTestCase):
         mock_execute.assert_has_calls([
             mock.call(['lsblk', '-Po',
                        'kname,pkname,name,label,type,fstype,mountpoint']),
+            mock.call(['sgdisk', '-v', '/dev/sda']),
             mock.call(['sgdisk', '--first-aligned-in-largest',
                        '--end-of-largest', '/dev/sda']),
             mock.call(['vgs', '--noheadings', '--options', 'vg_name']),
@@ -512,6 +527,7 @@ class TestGrowvols(base.BaseTestCase):
         mock_execute.reset_mock()
         mock_execute.side_effect = [
             LSBLK,
+            '',
             SGDISK_LARGEST,
             VGS,
             LVS,
@@ -522,6 +538,7 @@ class TestGrowvols(base.BaseTestCase):
         mock_execute.assert_has_calls([
             mock.call(['lsblk', '-Po',
                        'kname,pkname,name,label,type,fstype,mountpoint']),
+            mock.call(['sgdisk', '-v', '/dev/sda']),
             mock.call(['sgdisk', '--first-aligned-in-largest',
                        '--end-of-largest', '/dev/sda']),
             mock.call(['vgs', '--noheadings', '--options', 'vg_name']),
@@ -549,6 +566,7 @@ class TestGrowvols(base.BaseTestCase):
         sgdisk_largest = "%s\n%s\n" % (sector_start, sector_end)
         mock_execute.side_effect = [
             LSBLK,
+            '',
             sgdisk_largest,
             VGS,
             LVS,
@@ -561,6 +579,7 @@ class TestGrowvols(base.BaseTestCase):
         # no space to grow, success
         mock_execute.side_effect = [
             LSBLK,
+            '',
             sgdisk_largest,
             VGS,
             LVS,
@@ -579,16 +598,18 @@ class TestGrowvols(base.BaseTestCase):
         mock_execute.reset_mock()
         mock_execute.side_effect = [
             LSBLK,
+            '',
             SGDISK_LARGEST,
             VGS,
             LVS_THIN,
-            '', '', '', '', '', '', '', '', '', '', ''
+            '', '', '', '', '', '', '', '', '', '', '', ''
         ]
         growvols.main(['growvols', '--yes', '--group', 'vg',
                        '/home=20%', 'fs_var=40%'])
         mock_execute.assert_has_calls([
             mock.call(['lsblk', '-Po',
                        'kname,pkname,name,label,type,fstype,mountpoint']),
+            mock.call(['sgdisk', '-v', '/dev/sda']),
             mock.call(['sgdisk', '--first-aligned-in-largest',
                        '--end-of-largest', '/dev/sda']),
             mock.call(['vgs', '--noheadings', '--options', 'vg_name']),
@@ -599,13 +620,15 @@ class TestGrowvols(base.BaseTestCase):
             mock.call(['partprobe']),
             mock.call(['pvcreate', '/dev/sda5']),
             mock.call(['vgextend', 'vg', '/dev/sda5']),
-            mock.call(['lvextend', '-L+209404821504B',
+            mock.call(['lvextend', '--poolmetadatasize', '+1073741824B',
                        '/dev/mapper/vg-lv_thinpool', '/dev/sda5']),
-            mock.call(['lvextend', '--size', '+41880125440B',
+            mock.call(['lvextend', '-L+208326885376B',
+                       '/dev/mapper/vg-lv_thinpool', '/dev/sda5']),
+            mock.call(['lvextend', '--size', '+41662021632B',
                        '/dev/mapper/vg-lv_home']),
-            mock.call(['lvextend', '--size', '+83760250880B',
+            mock.call(['lvextend', '--size', '+83328237568B',
                        '/dev/mapper/vg-lv_var']),
-            mock.call(['lvextend', '--size', '+83764445184B',
+            mock.call(['lvextend', '--size', '+83336626176B',
                        '/dev/mapper/vg-lv_root']),
             mock.call(['xfs_growfs', '/dev/mapper/vg-lv_home']),
             mock.call(['xfs_growfs', '/dev/mapper/vg-lv_var']),
